==> sdlskk-0.1.tar.gz: sdlskk-0.1/testsdl.c <==
#include <sdlskk.h>
#include <SDL.h>
#include <SDL_ttf.h>
#include <iconv.h>

SDL_Surface* screen;
SDLSKK_Context* context;
SDLSKK_RomKanaRuleTable* table;
SDLSKK_Dictionary* dict;
TTF_Font* font;
iconv_t cd;

SDL_Color white = { 0xFF, 0xFF, 0xFF, 0 };

void init(void)
{
  dict = SDLSKK_Dict_new( "test_jisyo" );
  table = SDLSKK_RomKanaRuleTable_new();
  SDLSKK_RomKanaRuleTable_load( table, "test_rule_table" );
  context = SDLSKK_Context_new( dict, table );

  if( SDL_Init( SDL_INIT_VIDEO ) < 0 ){
    fprintf( stderr, "%s\n", SDL_GetError());
    exit(1);
  }
  atexit( SDL_Quit );
  if( TTF_Init() < 0 ){
    fprintf( stderr, "%s\n", SDL_GetError());
    exit(1);
  }
  atexit( TTF_Quit );

  font = TTF_OpenFont( "sample.ttf", 14 );
  if( font == NULL ){
    fprintf( stderr, "%s\n", SDL_GetError());
    exit(1);
  }
  
  screen = SDL_SetVideoMode( 640, 480, 16, SDL_SWSURFACE );
  if( screen == NULL ){
    fprintf( stderr, "%s\n", SDL_GetError());
    exit(1);
  }

  SDL_EnableUNICODE( 1 );
  cd = iconv_open( "UTF-8", "EUC-JP" );
  return;
}

char* eucjp2utf8( char* input, char* output, size_t output_size )
{
  char* o = output;
  size_t inbytesleft = strlen( input );
  while( inbytesleft > 0 ){
    if( iconv( cd, &input, &inbytesleft, &output, &output_size ) == -1 ){
      *output = '\0';
      iconv( cd, NULL, NULL, NULL, NULL );
      return NULL;
    }
  }
  iconv( cd, NULL, NULL, NULL, NULL );
  *output = '\0';
  return o;
}

int main(void)
{ 
  char buf[4098];
  SDL_Surface* tmp_surface;
  char unicode_buf[4098];
  SDL_Rect rect = { 0, 0, 640, 480 };
  
  init();
  
  for(;;){
    SDL_Event event;
    while( SDL_PollEvent(&event) ){
      switch(event.type){
      case SDL_KEYDOWN:
	if( event.key.keysym.sym == SDLK_ESCAPE )
	  return 0;
	SDLSKK_Context_input_event( context, &event );
	if( event.key.keysym.sym == SDLK_TAB )
	  printf( "%s\n", buf );
	break;
      case SDL_QUIT:
	return 0;
      }
      SDLSKK_Context_get_display_str( context, buf, sizeof( buf ) );
      eucjp2utf8( buf, unicode_buf, sizeof( unicode_buf ) );
      tmp_surface = TTF_RenderUTF8_Solid( font, unicode_buf, white );
      SDL_FillRect( screen, &rect, 0 );
      SDL_BlitSurface( tmp_surface, NULL, screen, NULL );
      SDL_Flip( screen );
      SDL_FreeSurface( tmp_surface );
      SDL_Delay( 50 );      
    }
  }
}

==> sdlskk-0.2.tar.gz: sdlskk-0.2/testsdl.c <==
#include <sdlskk.h>
#include <SDL.h>
#include <SDL_ttf.h>
#include <iconv.h>

SDL_Surface* screen;
SDLSKK_Context* context;
SDLSKK_RomKanaRuleTable* table;
SDLSKK_Dictionary* dict;
TTF_Font* font;
iconv_t cd;

SDL_Color white = { 0xFF, 0xFF, 0xFF, 0 };

void init(void)
{
  dict = SDLSKK_Dict_new();
  SDLSKK_Dict_load( dict, "test_jisyo", 0 );
  table = SDLSKK_RomKanaRuleTable_new( "test_rule_table" );
  context = SDLSKK_Context_new( dict, table );

  if( SDL_Init( SDL_INIT_VIDEO ) < 0 ){
    fprintf( stderr, "%s\n", SDL_GetError());
    exit(1);
  }
  atexit( SDL_Quit );
  if( TTF_Init() < 0 ){
    fprintf( stderr, "%s\n", SDL_GetError());
    exit(1);
  }
  atexit( TTF_Quit );

  font = TTF_OpenFont( "sample.ttf", 14 );
  if( font == NULL ){
    fprintf( stderr, "%s\n", SDL_GetError());
    exit(1);
  }
  
  screen = SDL_SetVideoMode( 640, 480, 16, SDL_SWSURFACE );
  if( screen == NULL ){
    fprintf( stderr, "%s\n", SDL_GetError());
    exit(1);
  }

  SDL_EnableUNICODE( 1 );
  cd = iconv_open( "UTF-8", "EUC-JP" );
  return;
}

char* eucjp2utf8( char* input, char* output, size_t output_size )
{
  char* o = output;
  size_t inbytesleft = strlen( input );
  while( inbytesleft > 0 ){
    if( iconv( cd, &input, &inbytesleft, &output, &output_size ) == -1 ){
      *output = '\0';
      iconv( cd, NULL, NULL, NULL, NULL );
      return NULL;
    }
  }
  iconv( cd, NULL, NULL, NULL, NULL );
  *output = '\0';
  return o;
}

int main(void)
{ 
  char buf[4098];
  SDL_Surface* tmp_surface;
  char unicode_buf[4098];
  SDL_Rect rect = { 0, 0, 640, 480 };
  
  init();
  
  for(;;){
    SDL_Event event;
    while( SDL_PollEvent(&event) ){
      switch(event.type){
      case SDL_KEYDOWN:
	if( event.key.keysym.sym == SDLK_ESCAPE )
	  return 0;
	SDLSKK_Context_input_event( context, &event );
	if( event.key.keysym.sym == SDLK_TAB )
	  printf( "%s\n", buf );
	break;
      case SDL_QUIT:
	return 0;
      }
      SDLSKK_Context_get_display_str( context, buf, sizeof( buf ) );
      eucjp2utf8( buf, unicode_buf, sizeof( unicode_buf ) );
      tmp_surface = TTF_RenderUTF8_Solid( font, unicode_buf, white );
      SDL_FillRect( screen, &rect, 0 );
      SDL_BlitSurface( tmp_surface, NULL, screen, NULL );
      SDL_Flip( screen );
      SDL_FreeSurface( tmp_surface );
      SDL_Delay( 50 );      
    }
  }
}
